from setuptools import setup

setup(name='dsnd_proba',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dsnd_proba'],
      author = "Syed Mustaqhim",
      author_email = "syedmustaqhim777@gmail.com", 
      zip_safe=False)
